==> nb_utils-4.2.6.tar.gz: lib/src/widgets/LanguageListWidget.dart <==
import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

class LanguageListWidget extends StatefulWidget {
  static String tag = '/LanguageSelectionWidget';
  final String? languageText;
  final void Function(LanguageDataModel)? onLanguageChange;

  LanguageListWidget({this.languageText, this.onLanguageChange});

  @override
  LanguageListWidgetState createState() => LanguageListWidgetState();
}

class LanguageListWidgetState extends State<LanguageListWidget> {
  @override
  void initState() {
    super.initState();
    init();
  }

  Future<void> init() async {
    //
  }

  @override
  void setState(fn) {
    if (mounted) super.setState(fn);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: ListView.builder(
        itemBuilder: (_, index) {
          LanguageDataModel data = localeLanguageList[index];

          return SettingItemWidget(
            title: widget.languageText.validate(value: 'App Language'),
            leading: Image.asset(data.flag.validate()),
            trailing: TextIcon(
              text: data.name.validate(),
              spacing: 8,
              prefix: Container(
                padding: EdgeInsets.all(2),
                decoration: boxDecorationDefault(
                    shape: BoxShape.circle, borderRadius: null),
                child: Icon(Icons.check, size: 15),
              ).visible(getStringAsync(SELECTED_LANGUAGE_CODE) ==
                  data.languageCode.validate()),
            ),
            onTap: () async {
              await setValue(SELECTED_LANGUAGE_CODE, data.languageCode);
              setState(() {});

              widget.onLanguageChange?.call(data);
            },
          );
        },
        shrinkWrap: true,
        itemCount: localeLanguageList.length,
      ),
    );
  }
}

==> nb_utils-4.2.8.tar.gz: lib/src/widgets/LanguageListWidget.dart <==
import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

class LanguageListWidget extends StatefulWidget {
  static String tag = '/LanguageSelectionWidget';
  final String? languageText;
  final void Function(LanguageDataModel)? onLanguageChange;
  final ScrollPhysics? scrollPhysics;

  LanguageListWidget(
      {this.languageText, this.onLanguageChange, this.scrollPhysics});

  @override
  LanguageListWidgetState createState() => LanguageListWidgetState();
}

class LanguageListWidgetState extends State<LanguageListWidget> {
  @override
  void initState() {
    super.initState();
    init();
  }

  Future<void> init() async {
    //
  }

  @override
  void setState(fn) {
    if (mounted) super.setState(fn);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: ListView.builder(
        itemBuilder: (_, index) {
          LanguageDataModel data = localeLanguageList[index];

          return SettingItemWidget(
            title: data.name.validate(),
            leading: Image.asset(data.flag.validate(), height: 24),
            trailing: Container(
              padding: EdgeInsets.all(2),
              decoration: boxDecorationDefault(
                  shape: BoxShape.circle, borderRadius: null),
              child: Icon(Icons.check, size: 15),
            ).visible(getStringAsync(SELECTED_LANGUAGE_CODE) ==
                data.languageCode.validate()),
            onTap: () async {
              await setValue(SELECTED_LANGUAGE_CODE, data.languageCode);
              setState(() {});

              widget.onLanguageChange?.call(data);
            },
          );
        },
        shrinkWrap: true,
        physics: widget.scrollPhysics,
        itemCount: localeLanguageList.length,
      ),
    );
  }
}
